#   This file is part of Dirby.
#
#   Foobar is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   Foobar is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with Foobar.  If not, see <http://www.gnu.org/licenses/>.

module Dirby

  # Manages loading and saving input lines across runs of IRB.
  class History

    def load_history
      real_path = File.expand_path("~/.irb_history")
      if File.exist?(real_path)
        lines = File.readlines(real_path).map {|line| line.chomp}
        Readline::HISTORY.push(*lines)
        puts "Read %d lines from history file %s" % [lines.size, real_path]
      else
        puts "No history to load."
      end
    end

    def save_history
      lines = Readline::HISTORY.to_a.uniq
      real_path = File.expand_path("~/.irb_history")
      File.open(real_path, File::WRONLY | File::CREAT | File::TRUNC) do |f|
        f.puts lines
      end
      puts "Saved %d lines to history file %s." % [lines.size, real_path]
    end

    def initialize(opts = {})
      return unless defined? Readline::HISTORY
      load_history
      Kernel.at_exit { save_history }
    end
  end
end
